oidc-provider.store

In-memory implementations of storage protocols for development and testing.

Clients should use :client-secret-hash (via oidc-provider.util/hash-client-secret) for credential storage.

In-memory implementations of storage protocols for development and testing.

Clients should use `:client-secret-hash` (via [[oidc-provider.util/hash-client-secret]])
for credential storage.
raw docstring

create-authorization-code-storeclj

(create-authorization-code-store)

Creates an in-memory [[InMemoryAuthorizationCodeStore]] backed by atoms for active codes and consumed-code token records.

Creates an in-memory [[InMemoryAuthorizationCodeStore]] backed by atoms for
active codes and consumed-code token records.
sourceraw docstring

create-client-storeclj

(create-client-store)
(create-client-store initial-clients)

Creates an in-memory [[InMemoryClientStore]]. When called with an initial-clients vector, pre-populates the store with those client configurations keyed by :client-id.

Creates an in-memory [[InMemoryClientStore]]. When called with an
`initial-clients` vector, pre-populates the store with those client
configurations keyed by `:client-id`.
sourceraw docstring

create-token-storeclj

(create-token-store)

Creates an in-memory [[InMemoryTokenStore]] with separate atoms for access tokens and refresh tokens.

Creates an in-memory [[InMemoryTokenStore]] with separate atoms for access
tokens and refresh tokens.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries