oidc-provider.ring

Ring handler for OAuth2 Dynamic Client Registration (RFC 7591/7592).

Provides registration-handler which returns a Ring handler supporting POST for client registration and GET for client configuration reads.

Ring handler for OAuth2 Dynamic Client Registration (RFC 7591/7592).

Provides [[registration-handler]] which returns a Ring handler supporting
POST for client registration and GET for client configuration reads.
raw docstring

registration-handlerclj

(registration-handler client-store & {:keys [initial-access-token]})

Creates a Ring handler for dynamic client registration.

Takes a client-store implementing oidc-provider.protocol/ClientStore and optional keyword arguments. When :initial-access-token is provided, POST requests require a matching Bearer token for gated registration.

Returns a Ring handler function that dispatches POST for registration and GET for client configuration reads.

Creates a Ring handler for dynamic client registration.

Takes a `client-store` implementing [[oidc-provider.protocol/ClientStore]]
and optional keyword arguments. When `:initial-access-token` is provided,
POST requests require a matching Bearer token for gated registration.

Returns a Ring handler function that dispatches POST for registration
and GET for client configuration reads.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries