oidc-provider.store

In-memory implementations of storage protocols for development and testing.

Clients should use :client-secret-hash (via oidc-provider.util/hash-client-secret) for credential storage.

In-memory implementations of storage protocols for development and testing.

Clients should use `:client-secret-hash` (via [[oidc-provider.util/hash-client-secret]])
for credential storage.
raw docstring

create-authorization-code-storeclj

(create-authorization-code-store)

Creates an in-memory authorization code store.

Returns: InMemoryAuthorizationCodeStore instance

Creates an in-memory authorization code store.

Returns:
  InMemoryAuthorizationCodeStore instance
raw docstring

create-client-storeclj

(create-client-store)
(create-client-store initial-clients)

Creates an in-memory client store.

Args: initial-clients: Optional vector of client configurations to pre-populate

Returns: InMemoryClientStore instance

Creates an in-memory client store.

Args:
  initial-clients: Optional vector of client configurations to pre-populate

Returns:
  InMemoryClientStore instance
raw docstring

create-token-storeclj

(create-token-store)

Creates an in-memory token store.

Returns: InMemoryTokenStore instance

Creates an in-memory token store.

Returns:
  InMemoryTokenStore instance
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries