In-memory implementations of storage protocols for development and testing.
Clients should use :client-secret-hash (via oidc-provider.util/hash-client-secret)
for credential storage.
In-memory implementations of storage protocols for development and testing. Clients should use `:client-secret-hash` (via [[oidc-provider.util/hash-client-secret]]) for credential storage.
(create-authorization-code-store)Creates an in-memory authorization code store.
Returns: InMemoryAuthorizationCodeStore instance
Creates an in-memory authorization code store. Returns: InMemoryAuthorizationCodeStore instance
(create-client-store)(create-client-store initial-clients)Creates an in-memory client store.
Args: initial-clients: Optional vector of client configurations to pre-populate
Returns: InMemoryClientStore instance
Creates an in-memory client store. Args: initial-clients: Optional vector of client configurations to pre-populate Returns: InMemoryClientStore instance
(create-token-store)Creates an in-memory token store.
Returns: InMemoryTokenStore instance
Creates an in-memory token store. Returns: InMemoryTokenStore instance
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |