In-memory implementations of storage protocols for development and testing.
These stores hold plaintext client secrets in memory and are not suitable for
production. Production deployments should use hashed secrets via the
:client-secret-hash field and oidc-provider.util/hash-client-secret.
In-memory implementations of storage protocols for development and testing. These stores hold plaintext client secrets in memory and are **not suitable for production**. Production deployments should use hashed secrets via the `:client-secret-hash` field and [[oidc-provider.util/hash-client-secret]].
(create-authorization-code-store)Creates an in-memory authorization code store.
Returns: InMemoryAuthorizationCodeStore instance
Creates an in-memory authorization code store. Returns: InMemoryAuthorizationCodeStore instance
(create-client-store)(create-client-store initial-clients)Creates an in-memory client store.
Args: initial-clients: Optional vector of client configurations to pre-populate
Returns: InMemoryClientStore instance
Creates an in-memory client store. Args: initial-clients: Optional vector of client configurations to pre-populate Returns: InMemoryClientStore instance
(create-token-store)Creates an in-memory token store.
Returns: InMemoryTokenStore instance
Creates an in-memory token store. Returns: InMemoryTokenStore instance
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |